| Type: | Package |
| Title: | F1 Pit Stop Datasets |
| Version: | 1.2.0 |
| Maintainer: | José Jordán-Soria <jjose.jjordan@gmail.com> |
| Description: | Formula 1 pit stop data. The package provides information on teams and drivers across seasons (2019 or higher). It also includes a function to visualize pit stop performance. |
| Imports: | dplyr, ggplot2, readr, tibble, httr, jsonlite, f1dataR |
| Suggests: | testthat (≥ 3.0.0), knitr, rmarkdown |
| VignetteBuilder: | knitr |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.2 |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-04-02 09:50:05 UTC; Jose |
| Author: | José Jordán-Soria [aut, cre] |
| Repository: | CRAN |
| Date/Publication: | 2026-04-02 10:20:02 UTC |
F1 pitstop ASCII art
Description
Funny ASCII F1 pitstop for title_text argument in pitplot() function
Usage
pitart(n = 1)
Arguments
n |
Integer. ASCII pit stop to generate. From 1 (by default) to 5 |
Format
ASCII string
Value
A string containing the ASCII art of a F1 pit stop
Examples
pitart(1)
pitart(2)
pitart(3)
pitart(5)
Pit stop standings by season
Description
Pit stop official standings by season (since 2015)
Usage
pitchamp(year)
Arguments
year |
Season pit stop standings (integer). 2015 or higher |
Value
A tibble containing the pit stop season standings points (or wins in 2015 and 2016)
Examples
pitchamp(2015)
Plot pit stop results
Description
Plot pit stop results (MUST BE in tibble format)
Usage
pitplot(pits_data, type = 3, title_text = NULL)
Arguments
pits_data |
Tibble data generated by the pits() function |
type |
Plot type: individual pit stop by driver (1), grouped by team (2), grouped by driver (3, by default) |
title_text |
Text for the plot title, in quotes (" ") (if is omitted, a default text will be used). |
Format
Tibble
Value
A ggplot object
Examples
pitplot(pits(10, 2025), 1, "Title: Hello world!")
Pit stops of a race or set
Description
Pit stop results of a race or set
Usage
pits(round, year)
Arguments
round |
Number of the race (integer), set of races a:b (vector) o "all" (character) |
year |
Year of the race (integer). 2019 or higher |
Value
A tibble containing the pit stops values of the specified race(s)
Examples
pits(10, 2025)
pits(1:2, 2025)